.nav-tabs-custom.main{
    margin: 1%;
    width: 48%;
}

.progress-bar-green, .progress-bar-success {
    background-color: #00A65A !important;
}

#id_settings_level{
    list-style: none;
    padding: 0;
}
